@@ -67,6 +67,13 @@ def gen_mod_hash_shift(mod_num, shift):
 
 
 class H5:
+    '''
+    H5DB的类
+    save_dir:<str>
+    logger_path:<int>
+    :return: 
+
+    '''
 
     def __init__(self,
                  save_dir: str = None,
@@ -76,6 +83,9 @@ class H5:
                  hash_l1: callable = None,
                  hash_l2: callable = None):
         self.save_dir = save_dir
+        if not os.path.exists(self.save_dir):
+            raise ValueError('invalid path for save_dir')
+
         self.logger = get_logger(logger_path)
         self.l1_size = l1_size
         self.l2_size = l2_size
@@ -89,8 +99,7 @@ class H5:
         else:
             self.hash_l2 = gen_mod_hash_shift(l2_size, l2_size)
 
-        if not os.path.exists(self.save_dir):
-            os.system('mkdir {}'.format(self.save_dir))
+
 
     @staticmethod
     def add_single_file(filename, data_pairs, hash_fuc):
